Kisee API
=========

The Kisee API exposes the following resources:

- A json-home on `/`
- `/jwt/` to manage tokens (mainly create a new one by POSTing)
- `/forgotten-passwords/` to initiate a password lost procedure and manage it.
- `POST /users/` for self-service registration.
